@@ -1,7 +1,7 @@
 analyzeGroup <-
 function(DF, xyTopLeft=TRUE, center=FALSE,
-         conversion="m2cm", bandW=0.5,
-         CEPtype="CorrNormal", bootCI=c("basic", "bca")) {
+         dstTarget, conversion, bandW=0.5,
+         CEPtype="CorrNormal", bootCI="none") {
     if(!is.data.frame(DF)) { stop("DF must be a data frame") }
 
     ## convert DF names to lower case
@@ -12,24 +12,15 @@ function(DF, xyTopLeft=TRUE, center=FALSE,
     varNames <- names(DF)                # what variables are present
     needsXY1 <- c("point.x", "point.y")  # coordinates must have this name
     needsXY2 <- c("x", "y")              # or this
-    wantsDst <- "distance"               # useful
     wantsAIM <- c("aim.x", "aim.y")      # useful
     hasXY1   <- needsXY1 %in% varNames
     hasXY2   <- needsXY2 %in% varNames
-    hasDst   <- wantsDst %in% varNames   # useful ones we have
     hasAIM   <- wantsAIM %in% varNames   # useful ones we have
 
     if(!xor(all(hasXY1), all(hasXY2))) {
         stop("Coordinates must be named either x, y or point.x, point.y")
     }
 
-    if(!all(hasDst)) {
-        warning(c("The data frame is missing variable\n",
-                  paste(wantsDst[!hasDst], collapse=" "), "\n",
-                  "Distance is assumed to be 100"))
-        DF$distance <- 100
-    }
-
     if(!all(hasAIM)) {
         warning(c("The data frame is missing variable(s)\n",
             paste(wantsAIM[!hasAIM], collapse=" "), "\n",
@@ -38,24 +29,33 @@ function(DF, xyTopLeft=TRUE, center=FALSE,
         DF$aim.y <- 0
     }
 
+    ## distance to target from override or from data
+    if(missing(dstTarget)) {
+        dstTarget <- if(hasName(DF, "distance")) {
+            DF[["distance"]]
+        } else {
+            NA_real_
+        }
+    }
+
+    ## determine conversion factor from data if override is not given
+    if(missing(conversion)) {
+        conversion <- determineConversion(DF)
+    }
+
     #####-----------------------------------------------------------------------
     ## prepare data: get (x,y)-coords relative to point of aim as matrix
     xy <- getXYmat(DF, xyTopLeft=xyTopLeft, center=center)
 
     #####-----------------------------------------------------------------------
     ## assess shape, location and spread
-    if(length(unique(DF$distance)) > 1L) {
-        warning("Distance to target is not homogeneous - using the average distance")
-    }
-
-    dstTrgt  <- mean(DF$distance)       # distance to target
     shape    <- groupShape(xy, plots=TRUE, bandW=bandW, outlier="mcd",
-                           dstTarget=dstTrgt, conversion=conversion)
+                           dstTarget=dstTarget, conversion=conversion)
     location <- groupLocation(xy, plots=FALSE, bootCI=bootCI, level=0.95,
-                              dstTarget=dstTrgt, conversion=conversion)
+                              dstTarget=dstTarget, conversion=conversion)
     spread   <- groupSpread(xy, plots=TRUE, CEPlevel=0.5, CIlevel=0.95,
                             CEPtype=CEPtype, bootCI=bootCI,
-                            dstTarget=dstTrgt, conversion=conversion)
+                            dstTarget=dstTarget, conversion=conversion)
 
     #####-----------------------------------------------------------------------
     ## return all the collected numerical results and tests
