@@ -1,10 +1,10 @@
 getRangeStat <-
-function(xy, dstTarget, conversion) {
+function(xy, dstTarget, conversion, CIlevel=0.95) {
     UseMethod("getRangeStat")
 }
 
 getRangeStat.data.frame <-
-function(xy, dstTarget, conversion) {
+function(xy, dstTarget, conversion, CIlevel=0.95) {
     ## distance to target from override or from data
     if(missing(dstTarget)) {
         dstTarget <- if(hasName(xy, "distance")) {
@@ -20,13 +20,13 @@ function(xy, dstTarget, conversion) {
     }
 
     xy <- getXYmat(xy, xyTopLeft=FALSE, center=FALSE, relPOA=FALSE)
-
-    getRangeStat(xy, dstTarget=dstTarget, conversion=conversion)
+    getRangeStat(xy, dstTarget=dstTarget, conversion=conversion,
+                 CIlevel=CIlevel)
     # NextMethod("getRangeStat")
 }
 
 getRangeStat.default <-
-function(xy, dstTarget, conversion) {
+function(xy, dstTarget, conversion, CIlevel=0.95) {
     xy <- as.matrix(xy)
     if(!is.numeric(xy))        { stop("xy must be numeric") }
 
@@ -46,8 +46,21 @@ function(xy, dstTarget, conversion) {
         unique(conversion)
     }
     
+    ## check if CIlevel is given in percent
+    if(CIlevel >= 1) {
+        while(CIlevel >= 1) { CIlevel <- CIlevel / 100 }
+        warning(c("CIlevel must be in (0,1) and was set to ", CIlevel))
+    }
+    
     bb  <- getBoundingBox(xy)
-    return(c(ES=getMaxPairDist(xy)$d,
-             FoM=bb$FoM,
-             D=bb$diag))
+    ES  <- getMaxPairDist(xy)[["d"]]
+    FoM <- bb$FoM
+    D   <- bb$diag
+    getRangeStatCI(c(ES, FoM, D),
+                   stat=c("ES", "FoM", "D"),
+                   n=nrow(xy),
+                   nGroups=1L,
+                   dstTarget=dstTarget,
+                   conversion=conversion,
+                   CIlevel=CIlevel)
 }
