@@ -5,15 +5,19 @@
 ## http://ballistipedia.com/index.php?title=Range_Statistics
 
 range2sigma <-
-function(x, stat="ES", n=5, nGroups=1, CIlevel=0.95, collapse=TRUE,
+function(x, stat="ES", n, nGroups, CIlevel=0.95, collapse=TRUE,
          dstTarget, conversion) {
     n       <- as.integer(n[1])
     nGroups <- as.integer(nGroups[1])
     stopifnot(all(x > 0),
-              n       > 1L, n       <= max(shotGroups::DFdistr$n),
-              nGroups > 0L, nGroups <= max(shotGroups::DFdistr$nGroups),
+              n       > 1L, n       <= max(shotGroups::DFdistr[["n"]]),
+              nGroups > 0L, nGroups <= max(shotGroups::DFdistr[["nGroups"]]),
               CIlevel > 0)
-    stat <- match.arg(toupper(stat), choices=c("ES", "FOM", "D"), several.ok=TRUE)
+    
+    stat <- match.arg(toupper(stat),
+                      choices=c("ES", "FOM", "D"),
+                      several.ok=TRUE)
+    
     argL <- recycle(x, stat)
     x    <- argL[[1]]
     stat <- c(ES="ES", FOM="FoM", D="D")[argL[[2]]]
@@ -42,26 +46,27 @@ function(x, stat="ES", n=5, nGroups=1, CIlevel=0.95, collapse=TRUE,
     }
     
     alpha    <- 1 - CIlevel
-    idxGroup <- which(shotGroups::DFdistr$nGroups == nGroups)
-    haveN    <- unique(shotGroups::DFdistr$n[idxGroup])
+    idxGroup <- which(shotGroups::DFdistr[["nGroups"]] == nGroups)
+    haveN    <- unique(shotGroups::DFdistr[["n"]][idxGroup])
     haveCI   <- c(0.5, 0.8, 0.9, 0.95, 0.99)
 
     ## Rayleigh sigma: use lookup table or monotone spline interpolation
     ## CI: use lookup table or Grubbs-Patnaik chi^2 approximation
     if(n %in% haveN) {
         ## can use lookup table for sigma estimate
-        idx <- which((shotGroups::DFdistr$n       == n) &
-                     (shotGroups::DFdistr$nGroups == nGroups))
+        idx <- which((shotGroups::DFdistr[["n"]]       == n) &
+                     (shotGroups::DFdistr[["nGroups"]] == nGroups))
+        
         M <- data.matrix(shotGroups::DFdistr[idx, paste0(stat, "_M"), drop=FALSE])
         M <- setNames(c(M), stat)
 
         ## for Grubbs-Patnaik ES-CI approximation
         if(!(CIlevel %in% haveCI)) {
-            ES_V    <- shotGroups::DFdistr$ES_V[idx]
-            ESSQ_M  <- shotGroups::DFdistr$ESSQ_M[idx]
-            ESSQ_V  <- shotGroups::DFdistr$ESSQ_V[idx]
-            # ES_SKEW <- shotGroups::DFdistr$ES_SKEW[idx]
-            # ES_KURT <- shotGroups::DFdistr$ES_KURT[idx]
+            ES_V   <- shotGroups::DFdistr[["ES_V"]][idx]
+            ESSQ_M <- shotGroups::DFdistr[["ESSQ_M"]][idx]
+            ESSQ_V <- shotGroups::DFdistr[["ESSQ_V"]][idx]
+            # ES_SKEW <- shotGroups::DFdistr[["ES_SKEW"]][idx]
+            # ES_KURT <- shotGroups::DFdistr[["ES_KURT"]][idx]
         }
     } else {
         ## spline interpolation for sigma estimate - M is monotonically increasing in n
@@ -69,18 +74,18 @@ function(x, stat="ES", n=5, nGroups=1, CIlevel=0.95, collapse=TRUE,
 
         ## only interpolate for requested number of groups
         M <- setNames(numeric(length(x)), stat)
-        M[names(M) == "ES"]  <- splinefun(haveN, shotGroups::DFdistr$ES_M[idxGroup],  method="monoH.FC")(n)
-        M[names(M) == "FoM"] <- splinefun(haveN, shotGroups::DFdistr$FoM_M[idxGroup], method="monoH.FC")(n)
-        M[names(M) == "D"]   <- splinefun(haveN, shotGroups::DFdistr$D_M[idxGroup],   method="monoH.FC")(n)
+        M[names(M) == "ES"]  <- splinefun(haveN, shotGroups::DFdistr[["ES_M"]][idxGroup],  method="monoH.FC")(n)
+        M[names(M) == "FoM"] <- splinefun(haveN, shotGroups::DFdistr[["FoM_M"]][idxGroup], method="monoH.FC")(n)
+        M[names(M) == "D"]   <- splinefun(haveN, shotGroups::DFdistr[["D_M"]][idxGroup],   method="monoH.FC")(n)
 
         ## spline interpolation for Grubbs-Patnaik ES-CI approximation
         ## M is monotonically increasing, but V, SKEW, KURT are not
         if(!(CIlevel %in% haveCI)) {
-            ES_V    <- splinefun(haveN, shotGroups::DFdistr$ES_V[idxGroup],    method="fmm")(n)
-            ESSQ_M  <- splinefun(haveN, shotGroups::DFdistr$ESSQ_M[idxGroup],  method="monoH.FC")(n)
-            ESSQ_V  <- splinefun(haveN, shotGroups::DFdistr$ESSQ_V[idxGroup],  method="fmm")(n)
-            # ES_SKEW <- splinefun(haveN, shotGroups::DFdistr$ES_SKEW[idxGroup], method="fmm")(n)
-            # ES_KURT <- splinefun(haveN, shotGroups::DFdistr$ES_KURT[idxGroup], method="fmm")(n)
+            ES_V   <- splinefun(haveN, shotGroups::DFdistr[["ES_V"]][idxGroup],    method="fmm")(n)
+            ESSQ_M <- splinefun(haveN, shotGroups::DFdistr[["ESSQ_M"]][idxGroup],  method="monoH.FC")(n)
+            ESSQ_V <- splinefun(haveN, shotGroups::DFdistr[["ESSQ_V"]][idxGroup],  method="fmm")(n)
+            # ES_SKEW <- splinefun(haveN, shotGroups::DFdistr[["ES_SKEW"]][idxGroup], method="fmm")(n)
+            # ES_KURT <- splinefun(haveN, shotGroups::DFdistr[["ES_KURT"]][idxGroup], method="fmm")(n)
         }
     }
 
@@ -185,52 +190,3 @@ function(x, stat="ES", n=5, nGroups=1, CIlevel=0.95, collapse=TRUE,
     Filter(function(l) { !is.null(l) && (length(l) > 0L) },
            list(sigma=sigma, sigmaCI=sigmaCI))
 }
-
-range2CEP <-
-function(x, stat="ES", n=5, nGroups=1, CEPlevel=0.5, CIlevel=0.95,
-         collapse=TRUE, dstTarget, conversion) {
-    sigma <- range2sigma(x=x, stat=stat, n=n, nGroups=nGroups,
-                         CIlevel=CIlevel, collapse=FALSE,
-                         dstTarget=dstTarget, conversion=conversion)
-    CEP <- qRayleigh(CEPlevel, scale=sigma$sigma)
-    CEP <- if(is.matrix(sigma$sigma)) {
-        dim(CEP)      <- dim(sigma$sigma)
-        rownames(CEP) <- rownames(sigma$sigma)
-        colnames(CEP) <- gsub("sigma", "CEP", colnames(sigma$sigma))
-        CEP
-    } else {
-        setNames(CEP, names(sigma$sigma))
-    }
-    
-    if(hasName(sigma, "sigmaCI")) {
-        CEPCI <- lapply(sigma$sigmaCI, function(y) {
-            lapply(y, function(z) {
-                res <- qRayleigh(CEPlevel, scale=z)
-                if(is.matrix(z)) {
-                    dim(res)      <- dim(z)
-                    rownames(res) <- rownames(z)
-                    colnames(res) <- gsub("sigma", "CEP", colnames(z))
-                }
-                
-                res
-            })
-        })
-
-        list(CEP=CEP, CEPCI=CEPCI)
-    } else {
-        list(CEP=CEP)
-    }
-
-    ## collapse sigmaCI list if required and possible
-    if(hasName(sigma, "sigmaCI") && collapse) {
-        for(i in seq_along(CEPCI)) {
-            if(length(CEPCI[[i]]) == 1L) { CEPCI[[i]] <- CEPCI[[c(i, 1)]] }
-        }
-        
-        if(length(CEPCI) == 1L) { CEPCI <- CEPCI[[1]] }
-        
-        list(CEP=CEP, CEPCI=CEPCI)
-    } else {
-        list(CEP=CEP)
-    }
-}
