@@ -91,7 +91,11 @@ shinyApp(
                             readDataSMT(fPath=dirname(fPath),  fNames=basename(fPath))
                         } else if(input$fileType == '4') {   ## ShotMarker e-target
                             readDataShotMarker(fPath=dirname(fPath),  fNames=basename(fPath))
-                        } else if(input$fileType == '5') {   ## other
+                        } else if(input$fileType == '5') {   ## SIUS e-target
+                            readDataSIUS(fPath=dirname(fPath),  fNames=basename(fPath))
+                        } else if(input$fileType == '6') {   ## Archery World Cup
+                            readDataArcheryWC(fPath=dirname(fPath),  fNames=basename(fPath))
+                        } else if(input$fileType == '7') {   ## other
                             readDataMisc(fPath=dirname(fPath), fNames=basename(fPath))
                         }
                     } else {
@@ -109,8 +113,12 @@ shinyApp(
                         readDataSMT(dirname(fPath),  fNames=basename(fPath))
                     } else if(input$fileType == '4') {   ## ShotMarker e-target
                         readDataShotMarker(dirname(fPath),  fNames=basename(fPath))
-                    } else if(input$fileType == '5') {   ## other
-                        readDataMisc(dirname(fPath), fNames=basename(fPath))
+                    } else if(input$fileType == '5') {   ## SIUS e-target
+                        readDataSIUS(fPath=dirname(fPath),  fNames=basename(fPath))
+                    } else if(input$fileType == '6') {   ## Archery World Cup
+                        readDataArcheryWC(fPath=dirname(fPath),  fNames=basename(fPath))
+                    } else if(input$fileType == '7') {   ## other
+                        readDataMisc(fPath=dirname(fPath), fNames=basename(fPath))
                     }
                 } else {
                     NULL
@@ -1055,6 +1063,7 @@ shinyApp(
                           bbMin=input$trgtBBmin,
                           bbDiag=input$trgtBBdiag,
                           minCirc=input$trgtMinCirc,
+                          minEll=input$trgtMinEll,
                           maxSpread=input$trgtMaxSpread,
                           meanDist=input$trgtMeanDist,
                           confEll=input$trgtConfEll,
