@@ -11,22 +11,26 @@ dashboardSidebar(
         menuItem(
             tagList("Range stats", icon("arrow-right", lib="font-awesome"), "Rayleigh \U03C3"),
             tabName="tab_sigma",
-            icon=icon("circle-thin", lib="font-awesome")
+            icon = tags$i(class = "far fa-circle")
+            # icon = icon("circle-thin", lib="font-awesome")
         ),
         menuItem(
             "Efficiency: # of groups",
             tabName="tab_n_groups",
-            icon=icon("circle-thin", lib="font-awesome")
+            icon = tags$i(class = "far fa-circle")
+            # icon = icon("circle-thin", lib="font-awesome")
         ),
         menuItem(
             "Efficiency: CI width",
             tabName="tab_ci_width",
-            icon=icon("circle-thin", lib="font-awesome")
+            icon = tags$i(class = "far fa-circle")
+            # icon = icon("circle-thin", lib="font-awesome")
         ),
         menuItem(
             "About",
             tabName="tab_about",
-            icon=icon("lightbulb", lib="font-awesome")
+            icon = tags$i(class = "far fa-circle")
+            # icon = icon("circle-thin", lib="font-awesome")
         )
     )
 )
